************************************************************************************
***Table 2B: Elite capture in PKH experiment ***************************************
************************************************************************************

clear
clear matrix
clear mata
set more off
set mem 256m
set sortseed 10000


*********************************
*1. Inputting data***************
*********************************

*** Actual beneficiaries ***
u "$originaldata/Endline2/hh_ad.dta", clear
keep hhid ad03
recode ad03 (3=0)
rename ad03 gotPKH
tempfile actual_bene
sa `actual_bene', replace

*** Other ***
u "$codeddata/Baseline/coded_baseline_partV_hybrid", clear
merge 1:1 hhid using "$codeddata/Baseline/coded_poor5_partV_hybrid.dta"
drop if _merge==2
drop _merge

*** Elite ***
merge 1:1 hhid using "$codeddata/Baseline/elite_measures.dta"
keep if _merge==3
drop _merge
merge 1:1 hhid using `actual_bene'
drop if _merge==2
drop _merge




*********************************
*2. Coding***********************
*********************************

*** Treatment status ***
gen PMT=(hybrid==0)
gen elite_sub=(tokohsubtreatment==1)

*** Interaction ***
gen eliterel_elitesub_1=elite_related_1*elite_sub






*********************************
*3. Analysis*********************
*********************************

* Actual benefit receipt

label var elite_related_1 "Elite"
label var logconsumption "Log Consumption"
label var elite_sub "Elite Subtreatment"
label var eliterel_elitesub_1 "Elite x Elite Subtreatment"


areg gotPKH elite_related_1 logconsumption  if PMT==1, ab(kecagroup) cl(hhea)
qui summ gotPKH if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Appendix Table 1B.doc", label nor2 nocons word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("PMT") replace

areg gotPKH elite_related_1 logconsumption if hybrid==1, ab(kecagroup) cl(hhea)
qui summ gotPKH if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Appendix Table 1B.doc", label nor2 nocons word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("Community") append

areg gotPKH elite_related_1 logconsumption elite_sub  eliterel_elitesub_1 if hybrid==1, ab(kecagroup) cl(hhea)
qui summ gotPKH if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Appendix Table 1B.doc", label nor2 nocons word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("Community") append


* Test for difference between column 1 and column 2
qui {
g hycons = hybrid*logconsumption
g hyeli_1 = hybrid*elite_related_1
egen interact = group(hybrid kecagroup)
areg gotPKH elite_related_1 logconsumption hybrid hycons hyeli_1, ab(interact) cl(hhea)
test _b[hybrid] = 0, notest
noi test _b[hyeli_1] = 0, accum
}

